@@ -27,6 +27,6 @@
 #define URL_FILE       "/home/jdfulmer/etc/urls.txt"
 #define CNF_FILE       "/home/jdfulmer/etc/siegerc"
 #define LOG_FILE       "/home/jdfulmer/var/log/siege.log"
-#define PLATFORM       "unknown-x86_64-linux-gnu"
+#define PLATFORM       "pc-x86_64-linux-gnu"
 
 #endif/*JOEDOG_PATH_H*/
