@@ -46,10 +46,10 @@
 #include <openssl/err.h>
 #include <openssl/rand.h>
 #include <openssl/pem.h>
-
+#include <openssl/tls1.h>
 #endif/*HAVE_SSL*/
 
-BOOLEAN SSL_initialize(CONN *C);
+BOOLEAN SSL_initialize(CONN *C, const char *servername);
 void    SSL_thread_setup(void);
 void    SSL_thread_cleanup(void);
 
